@@ -3,7 +3,6 @@ import argparse
 import json
 import os
 import signal
-import socket
 import subprocess
 import sys
 import time
@@ -12,7 +11,6 @@ from glob import glob
 
 from livesync import Mutex
 
-hostname = socket.gethostname()
 processes: list[subprocess.Popen] = []
 
 
@@ -21,15 +19,23 @@ def start_process(command: str) -> None:
     processes.append(proc)
 
 
+def parse_ignore_file(path: str) -> list[str]:
+    if not os.path.isfile(path):
+        return []
+    with open(path) as f:
+        return [line.strip() for line in f.readlines() if not line.startswith('#')]
+
+
 def sync(path: str, target_host: str) -> None:
     if not os.path.isdir(path):
         return
     print(f'start syncing "{path}"')
-    EXCLUDES = ['.git/', '__pycache__/', 'gphoto/', '.DS_Store', '.pytest_cache', '.vscode', '.github', 'tests']
-    excludes = ' '.join([f'--exclude="{e}"' for e in EXCLUDES])
-    rsync = f'rsync --prune-empty-dirs --delete -avz --itemize-changes {excludes} {path}/ {target_host}:{os.path.basename(os.path.realpath(path))}'
+    excludes = ['.git/', '__pycache__/', '.DS_Store'] \
+        + parse_ignore_file(f'{path}/.syncignore') + parse_ignore_file(f'{path}/.gitignore')
+    exclude_params = ' '.join([f'--exclude="{e}"' for e in excludes])
+    rsync = f'rsync --prune-empty-dirs --delete -avz --itemize-changes {exclude_params} {path}/ {target_host}:{os.path.basename(os.path.realpath(path))}'
     start_process(rsync)
-    start_process(f'fswatch -r -l 0.1 -o {path} {excludes} | xargs -n1 -I{{}} {rsync}')
+    start_process(f'fswatch -r -l 0.1 -o {path} {exclude_params} | xargs -n1 -I{{}} {rsync}')
 
 
 def main():
@@ -39,7 +45,7 @@ def main():
     args = parser.parse_args()
 
     mutex = Mutex(args.host)
-    if not mutex.set(hostname):
+    if not mutex.set():
         print(f'Target is in use by {mutex.occupant}')
         sys.exit(1)
     with open(glob('*.code-workspace')[0]) as f:
@@ -47,7 +53,7 @@ def main():
     try:
         for p in workspace['folders']:
             sync(p['path'], args.host)
-        while mutex.set(hostname):
+        while mutex.set():
             for i in range(100):
                 for p in processes:
                     # make stdout non-blocking (https://stackoverflow.com/a/59291466/364388)
