@@ -1,4 +1,5 @@
 import logging
+import socket
 import subprocess
 import time
 
@@ -8,30 +9,28 @@ class Mutex:
     def __init__(self, host: str) -> None:
         self.host = host
         self.occupant: str = None
+        self.user_id = socket.gethostname()
 
-    def is_free(self, user_id: str) -> bool:
+    def is_free(self) -> bool:
         try:
             output = subprocess.check_output(
-                ['ssh', self.host, 'cat ~/.sync_mutex'],
+                ['ssh', self.host, f'cat ~/.livesync_mutex || echo "{self.tag}"'],
                 stderr=subprocess.DEVNULL).decode()
-        except subprocess.CalledProcessError:
-            return True
-        try:
             words = output.strip().split()
             self.occupant = words[0]
-            occupant_ok = self.occupant == user_id
+            occupant_ok = self.occupant == self.user_id
             time_elapsed = time.time() - float(words[1]) > 15
             return occupant_ok or time_elapsed
         except:
             logging.exception('Could not read mutex file')
             return False
 
-    def set(self, user_id: str) -> bool:
-        if not self.is_free(user_id):
+    def set(self) -> bool:
+        if not self.is_free():
             return False
         try:
             subprocess.check_output(
-                ['ssh', self.host, f'echo "{user_id} {time.time():.3f}" > ~/.sync_mutex'],
+                ['ssh', self.host, f'echo "{self.tag}" > ~/.livesync_mutex'],
                 stderr=subprocess.DEVNULL
             )
             return True
@@ -41,8 +40,12 @@ class Mutex:
 
     def remove(self) -> None:
         try:
-            subprocess.check_output(['ssh', self.host, f'rm ~/.sync_mutex'], stderr=subprocess.DEVNULL)
+            subprocess.check_output(['ssh', self.host, f'rm ~/.livesync_mutex'], stderr=subprocess.DEVNULL)
             return True
         except subprocess.CalledProcessError:
             print('Could not remove mutex file')
             return False
+
+    @property
+    def tag(self) -> str:
+        return f'{self.user_id} {time.time():.3f}'
